Type: Package
Package: indiedown
Title: Individual R Markdown Templates
Version: 0.1.1
Authors@R: 
    c(person(given = "Christoph",
             family = "Sax",
             role = c("aut", "cre"),
             email = "christoph.sax@gmail.com",
             comment = c(ORCID = "0000-0002-7192-7044")),
      person(given = "Kirill",
             family = "Müller",
             role = "aut",
             comment = c(ORCID = "0000-0002-1416-3412")),
      person(given = "Angelica",
             family = "Becerra",
             role = "aut"),
      person(given = "Frederik",
             family = "Aust",
             role = "aut"),
      person(given = "cynkra GmbH",
             role = c("fnd", "cph"),
             email = "mail@cynkra.com"))
Description: Simplifies the generation of customized R Markdown PDF templates.
    A template may include an individual logo, typography, geometry or color
    scheme. The package provides a skeleton with detailed instructions for
    customizations. The skeleton can be modified by changing defaults in the
    'YAML' header, by adding additional 'LaTeX' commands or by applying dynamic
    adjustments in R. Individual corporate design elements, such as a title page, can be added as R functions that produce 'LaTeX' code.
License: MIT + file LICENSE
URL: https://cynkra.github.io/indiedown/,
        https://github.com/cynkra/indiedown
BugReports: https://github.com/cynkra/indiedown/issues
Depends: R (>= 4.0.0)
Imports: cli, fs, gfonts, rlang, withr
Suggests: callr, knitr (>= 1.12), rcmdcheck, rmarkdown, spelling,
        testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
LazyData: TRUE
RoxygenNote: 7.1.1
NeedsCompilation: no
Packaged: 2021-03-21 08:49:06 UTC; christoph
Author: Christoph Sax [aut, cre] (<https://orcid.org/0000-0002-7192-7044>),
  Kirill Müller [aut] (<https://orcid.org/0000-0002-1416-3412>),
  Angelica Becerra [aut],
  Frederik Aust [aut],
  cynkra GmbH [fnd, cph]
Maintainer: Christoph Sax <christoph.sax@gmail.com>
Repository: CRAN
Date/Publication: 2021-03-22 15:30:06 UTC
Built: R 4.6.0; ; 2026-04-26 13:33:55 UTC; unix
