Package: mypackage
Title: Acme Inc. Corporate Design R Markdown Template
Version: 0.1
Authors@R:
    person(given = "First",
           family = "Last",
           role = c("aut", "cre"),
           email = "first.last@example.com")
Description: Provides an R Markdown template conforming to the
    corporate design guidelines at Acme Inc.
License: file LICENSE
Depends:
    R (>= 4.0.0)
Imports:
    glue,
    knitr (>= 1.12),
    rmarkdown,
    utils,
    withr,
    yaml
Encoding: UTF-8
LazyData: true
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.1.1
