% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/indiedown_pdf_document.R
\name{mypackage}
\alias{mypackage}
\title{Customized R Markdown Document}
\usage{
mypackage(...)
}
\arguments{
\item{...}{Passed on to \code{\link[rmarkdown:pdf_document]{rmarkdown::pdf_document()}}.}
}
\value{
R Markdown output format to pass to \code{\link[rmarkdown:render]{rmarkdown::render()}}.
}
\description{
\code{mypackage()} is the main function of the mypackage package. Use as
\code{output: mypackage::mypackage} in the R Markdown YAML header.
}
